# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsSourcePattern(object):
    """
    LogAnalyticsSourcePattern
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsSourcePattern object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param converted_text:
            The value to assign to the converted_text property of this LogAnalyticsSourcePattern.
        :type converted_text: str

        :param db_parser_id:
            The value to assign to the db_parser_id property of this LogAnalyticsSourcePattern.
        :type db_parser_id: int

        :param db_pattern_date_time_columns:
            The value to assign to the db_pattern_date_time_columns property of this LogAnalyticsSourcePattern.
        :type db_pattern_date_time_columns: str

        :param db_pattern_date_time_field:
            The value to assign to the db_pattern_date_time_field property of this LogAnalyticsSourcePattern.
        :type db_pattern_date_time_field: str

        :param db_pattern_sequence_column:
            The value to assign to the db_pattern_sequence_column property of this LogAnalyticsSourcePattern.
        :type db_pattern_sequence_column: str

        :param fields:
            The value to assign to the fields property of this LogAnalyticsSourcePattern.
        :type fields: list[oci.log_analytics.models.LogAnalyticsParserField]

        :param is_include:
            The value to assign to the is_include property of this LogAnalyticsSourcePattern.
        :type is_include: bool

        :param is_default:
            The value to assign to the is_default property of this LogAnalyticsSourcePattern.
        :type is_default: bool

        :param pattern_filter:
            The value to assign to the pattern_filter property of this LogAnalyticsSourcePattern.
        :type pattern_filter: oci.log_analytics.models.LogAnalyticsPatternFilter

        :param alias:
            The value to assign to the alias property of this LogAnalyticsSourcePattern.
        :type alias: str

        :param description:
            The value to assign to the description property of this LogAnalyticsSourcePattern.
        :type description: str

        :param is_enabled:
            The value to assign to the is_enabled property of this LogAnalyticsSourcePattern.
        :type is_enabled: bool

        :param pattern_id:
            The value to assign to the pattern_id property of this LogAnalyticsSourcePattern.
        :type pattern_id: int

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsSourcePattern.
        :type is_system: bool

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsSourcePattern.
        :type source_id: int

        :param is_agent_warning_suppressed:
            The value to assign to the is_agent_warning_suppressed property of this LogAnalyticsSourcePattern.
        :type is_agent_warning_suppressed: bool

        :param pattern_text:
            The value to assign to the pattern_text property of this LogAnalyticsSourcePattern.
        :type pattern_text: str

        :param pattern_type:
            The value to assign to the pattern_type property of this LogAnalyticsSourcePattern.
        :type pattern_type: int

        :param entity_type:
            The value to assign to the entity_type property of this LogAnalyticsSourcePattern.
        :type entity_type: list[str]

        """
        self.swagger_types = {
            'converted_text': 'str',
            'db_parser_id': 'int',
            'db_pattern_date_time_columns': 'str',
            'db_pattern_date_time_field': 'str',
            'db_pattern_sequence_column': 'str',
            'fields': 'list[LogAnalyticsParserField]',
            'is_include': 'bool',
            'is_default': 'bool',
            'pattern_filter': 'LogAnalyticsPatternFilter',
            'alias': 'str',
            'description': 'str',
            'is_enabled': 'bool',
            'pattern_id': 'int',
            'is_system': 'bool',
            'source_id': 'int',
            'is_agent_warning_suppressed': 'bool',
            'pattern_text': 'str',
            'pattern_type': 'int',
            'entity_type': 'list[str]'
        }

        self.attribute_map = {
            'converted_text': 'convertedText',
            'db_parser_id': 'dbParserId',
            'db_pattern_date_time_columns': 'dbPatternDateTimeColumns',
            'db_pattern_date_time_field': 'dbPatternDateTimeField',
            'db_pattern_sequence_column': 'dbPatternSequenceColumn',
            'fields': 'fields',
            'is_include': 'isInclude',
            'is_default': 'isDefault',
            'pattern_filter': 'patternFilter',
            'alias': 'alias',
            'description': 'description',
            'is_enabled': 'isEnabled',
            'pattern_id': 'patternId',
            'is_system': 'isSystem',
            'source_id': 'sourceId',
            'is_agent_warning_suppressed': 'isAgentWarningSuppressed',
            'pattern_text': 'patternText',
            'pattern_type': 'patternType',
            'entity_type': 'entityType'
        }

        self._converted_text = None
        self._db_parser_id = None
        self._db_pattern_date_time_columns = None
        self._db_pattern_date_time_field = None
        self._db_pattern_sequence_column = None
        self._fields = None
        self._is_include = None
        self._is_default = None
        self._pattern_filter = None
        self._alias = None
        self._description = None
        self._is_enabled = None
        self._pattern_id = None
        self._is_system = None
        self._source_id = None
        self._is_agent_warning_suppressed = None
        self._pattern_text = None
        self._pattern_type = None
        self._entity_type = None

    @property
    def converted_text(self):
        """
        Gets the converted_text of this LogAnalyticsSourcePattern.
        The converted text.


        :return: The converted_text of this LogAnalyticsSourcePattern.
        :rtype: str
        """
        return self._converted_text

    @converted_text.setter
    def converted_text(self, converted_text):
        """
        Sets the converted_text of this LogAnalyticsSourcePattern.
        The converted text.


        :param converted_text: The converted_text of this LogAnalyticsSourcePattern.
        :type: str
        """
        self._converted_text = converted_text

    @property
    def db_parser_id(self):
        """
        Gets the db_parser_id of this LogAnalyticsSourcePattern.
        The parser unique identifier.


        :return: The db_parser_id of this LogAnalyticsSourcePattern.
        :rtype: int
        """
        return self._db_parser_id

    @db_parser_id.setter
    def db_parser_id(self, db_parser_id):
        """
        Sets the db_parser_id of this LogAnalyticsSourcePattern.
        The parser unique identifier.


        :param db_parser_id: The db_parser_id of this LogAnalyticsSourcePattern.
        :type: int
        """
        self._db_parser_id = db_parser_id

    @property
    def db_pattern_date_time_columns(self):
        """
        Gets the db_pattern_date_time_columns of this LogAnalyticsSourcePattern.
        The date time columns.


        :return: The db_pattern_date_time_columns of this LogAnalyticsSourcePattern.
        :rtype: str
        """
        return self._db_pattern_date_time_columns

    @db_pattern_date_time_columns.setter
    def db_pattern_date_time_columns(self, db_pattern_date_time_columns):
        """
        Sets the db_pattern_date_time_columns of this LogAnalyticsSourcePattern.
        The date time columns.


        :param db_pattern_date_time_columns: The db_pattern_date_time_columns of this LogAnalyticsSourcePattern.
        :type: str
        """
        self._db_pattern_date_time_columns = db_pattern_date_time_columns

    @property
    def db_pattern_date_time_field(self):
        """
        Gets the db_pattern_date_time_field of this LogAnalyticsSourcePattern.
        The date time field.


        :return: The db_pattern_date_time_field of this LogAnalyticsSourcePattern.
        :rtype: str
        """
        return self._db_pattern_date_time_field

    @db_pattern_date_time_field.setter
    def db_pattern_date_time_field(self, db_pattern_date_time_field):
        """
        Sets the db_pattern_date_time_field of this LogAnalyticsSourcePattern.
        The date time field.


        :param db_pattern_date_time_field: The db_pattern_date_time_field of this LogAnalyticsSourcePattern.
        :type: str
        """
        self._db_pattern_date_time_field = db_pattern_date_time_field

    @property
    def db_pattern_sequence_column(self):
        """
        Gets the db_pattern_sequence_column of this LogAnalyticsSourcePattern.
        The sequence column.


        :return: The db_pattern_sequence_column of this LogAnalyticsSourcePattern.
        :rtype: str
        """
        return self._db_pattern_sequence_column

    @db_pattern_sequence_column.setter
    def db_pattern_sequence_column(self, db_pattern_sequence_column):
        """
        Sets the db_pattern_sequence_column of this LogAnalyticsSourcePattern.
        The sequence column.


        :param db_pattern_sequence_column: The db_pattern_sequence_column of this LogAnalyticsSourcePattern.
        :type: str
        """
        self._db_pattern_sequence_column = db_pattern_sequence_column

    @property
    def fields(self):
        """
        Gets the fields of this LogAnalyticsSourcePattern.
        The parser field list.


        :return: The fields of this LogAnalyticsSourcePattern.
        :rtype: list[oci.log_analytics.models.LogAnalyticsParserField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this LogAnalyticsSourcePattern.
        The parser field list.


        :param fields: The fields of this LogAnalyticsSourcePattern.
        :type: list[oci.log_analytics.models.LogAnalyticsParserField]
        """
        self._fields = fields

    @property
    def is_include(self):
        """
        Gets the is_include of this LogAnalyticsSourcePattern.
        A flag indicating if this is source pattern is included.


        :return: The is_include of this LogAnalyticsSourcePattern.
        :rtype: bool
        """
        return self._is_include

    @is_include.setter
    def is_include(self, is_include):
        """
        Sets the is_include of this LogAnalyticsSourcePattern.
        A flag indicating if this is source pattern is included.


        :param is_include: The is_include of this LogAnalyticsSourcePattern.
        :type: bool
        """
        self._is_include = is_include

    @property
    def is_default(self):
        """
        Gets the is_default of this LogAnalyticsSourcePattern.
        A flag indicating if this is the default source pattern.


        :return: The is_default of this LogAnalyticsSourcePattern.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this LogAnalyticsSourcePattern.
        A flag indicating if this is the default source pattern.


        :param is_default: The is_default of this LogAnalyticsSourcePattern.
        :type: bool
        """
        self._is_default = is_default

    @property
    def pattern_filter(self):
        """
        Gets the pattern_filter of this LogAnalyticsSourcePattern.

        :return: The pattern_filter of this LogAnalyticsSourcePattern.
        :rtype: oci.log_analytics.models.LogAnalyticsPatternFilter
        """
        return self._pattern_filter

    @pattern_filter.setter
    def pattern_filter(self, pattern_filter):
        """
        Sets the pattern_filter of this LogAnalyticsSourcePattern.

        :param pattern_filter: The pattern_filter of this LogAnalyticsSourcePattern.
        :type: oci.log_analytics.models.LogAnalyticsPatternFilter
        """
        self._pattern_filter = pattern_filter

    @property
    def alias(self):
        """
        Gets the alias of this LogAnalyticsSourcePattern.
        The source pattern alias.


        :return: The alias of this LogAnalyticsSourcePattern.
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """
        Sets the alias of this LogAnalyticsSourcePattern.
        The source pattern alias.


        :param alias: The alias of this LogAnalyticsSourcePattern.
        :type: str
        """
        self._alias = alias

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsSourcePattern.
        The source pattern description.


        :return: The description of this LogAnalyticsSourcePattern.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsSourcePattern.
        The source pattern description.


        :param description: The description of this LogAnalyticsSourcePattern.
        :type: str
        """
        self._description = description

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this LogAnalyticsSourcePattern.
        A flag inidcating whether or not the source pattern is enabled.


        :return: The is_enabled of this LogAnalyticsSourcePattern.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this LogAnalyticsSourcePattern.
        A flag inidcating whether or not the source pattern is enabled.


        :param is_enabled: The is_enabled of this LogAnalyticsSourcePattern.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def pattern_id(self):
        """
        Gets the pattern_id of this LogAnalyticsSourcePattern.
        The source pattern unique identifier.


        :return: The pattern_id of this LogAnalyticsSourcePattern.
        :rtype: int
        """
        return self._pattern_id

    @pattern_id.setter
    def pattern_id(self, pattern_id):
        """
        Sets the pattern_id of this LogAnalyticsSourcePattern.
        The source pattern unique identifier.


        :param pattern_id: The pattern_id of this LogAnalyticsSourcePattern.
        :type: int
        """
        self._pattern_id = pattern_id

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsSourcePattern.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :return: The is_system of this LogAnalyticsSourcePattern.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsSourcePattern.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :param is_system: The is_system of this LogAnalyticsSourcePattern.
        :type: bool
        """
        self._is_system = is_system

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsSourcePattern.
        The source unique identifier.


        :return: The source_id of this LogAnalyticsSourcePattern.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsSourcePattern.
        The source unique identifier.


        :param source_id: The source_id of this LogAnalyticsSourcePattern.
        :type: int
        """
        self._source_id = source_id

    @property
    def is_agent_warning_suppressed(self):
        """
        Gets the is_agent_warning_suppressed of this LogAnalyticsSourcePattern.
        A flag indicating whether or not agent warnings are suppressed for
        this source pattern.


        :return: The is_agent_warning_suppressed of this LogAnalyticsSourcePattern.
        :rtype: bool
        """
        return self._is_agent_warning_suppressed

    @is_agent_warning_suppressed.setter
    def is_agent_warning_suppressed(self, is_agent_warning_suppressed):
        """
        Sets the is_agent_warning_suppressed of this LogAnalyticsSourcePattern.
        A flag indicating whether or not agent warnings are suppressed for
        this source pattern.


        :param is_agent_warning_suppressed: The is_agent_warning_suppressed of this LogAnalyticsSourcePattern.
        :type: bool
        """
        self._is_agent_warning_suppressed = is_agent_warning_suppressed

    @property
    def pattern_text(self):
        """
        Gets the pattern_text of this LogAnalyticsSourcePattern.
        The pattern text.


        :return: The pattern_text of this LogAnalyticsSourcePattern.
        :rtype: str
        """
        return self._pattern_text

    @pattern_text.setter
    def pattern_text(self, pattern_text):
        """
        Sets the pattern_text of this LogAnalyticsSourcePattern.
        The pattern text.


        :param pattern_text: The pattern_text of this LogAnalyticsSourcePattern.
        :type: str
        """
        self._pattern_text = pattern_text

    @property
    def pattern_type(self):
        """
        Gets the pattern_type of this LogAnalyticsSourcePattern.
        The pattern type.


        :return: The pattern_type of this LogAnalyticsSourcePattern.
        :rtype: int
        """
        return self._pattern_type

    @pattern_type.setter
    def pattern_type(self, pattern_type):
        """
        Sets the pattern_type of this LogAnalyticsSourcePattern.
        The pattern type.


        :param pattern_type: The pattern_type of this LogAnalyticsSourcePattern.
        :type: int
        """
        self._pattern_type = pattern_type

    @property
    def entity_type(self):
        """
        Gets the entity_type of this LogAnalyticsSourcePattern.
        The source entity type.


        :return: The entity_type of this LogAnalyticsSourcePattern.
        :rtype: list[str]
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this LogAnalyticsSourcePattern.
        The source entity type.


        :param entity_type: The entity_type of this LogAnalyticsSourcePattern.
        :type: list[str]
        """
        self._entity_type = entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateOggDeploymentDetails(object):
    """
    Deployment Details for updating an OggDeployment
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateOggDeploymentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param admin_username:
            The value to assign to the admin_username property of this UpdateOggDeploymentDetails.
        :type admin_username: str

        :param admin_password:
            The value to assign to the admin_password property of this UpdateOggDeploymentDetails.
        :type admin_password: str

        :param certificate:
            The value to assign to the certificate property of this UpdateOggDeploymentDetails.
        :type certificate: str

        :param key:
            The value to assign to the key property of this UpdateOggDeploymentDetails.
        :type key: str

        """
        self.swagger_types = {
            'admin_username': 'str',
            'admin_password': 'str',
            'certificate': 'str',
            'key': 'str'
        }

        self.attribute_map = {
            'admin_username': 'adminUsername',
            'admin_password': 'adminPassword',
            'certificate': 'certificate',
            'key': 'key'
        }

        self._admin_username = None
        self._admin_password = None
        self._certificate = None
        self._key = None

    @property
    def admin_username(self):
        """
        Gets the admin_username of this UpdateOggDeploymentDetails.
        The GoldenGate deployment console username.


        :return: The admin_username of this UpdateOggDeploymentDetails.
        :rtype: str
        """
        return self._admin_username

    @admin_username.setter
    def admin_username(self, admin_username):
        """
        Sets the admin_username of this UpdateOggDeploymentDetails.
        The GoldenGate deployment console username.


        :param admin_username: The admin_username of this UpdateOggDeploymentDetails.
        :type: str
        """
        self._admin_username = admin_username

    @property
    def admin_password(self):
        """
        Gets the admin_password of this UpdateOggDeploymentDetails.
        The password associated with the GoldenGate deployment console username. The password must be 8 to 30 characters long and must contain at least 1 uppercase, 1 lowercase, 1 numeric, and 1 special character. Special characters such as \u2018$\u2019, \u2018^\u2019, or \u2018?\u2019 are not allowed.


        :return: The admin_password of this UpdateOggDeploymentDetails.
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """
        Sets the admin_password of this UpdateOggDeploymentDetails.
        The password associated with the GoldenGate deployment console username. The password must be 8 to 30 characters long and must contain at least 1 uppercase, 1 lowercase, 1 numeric, and 1 special character. Special characters such as \u2018$\u2019, \u2018^\u2019, or \u2018?\u2019 are not allowed.


        :param admin_password: The admin_password of this UpdateOggDeploymentDetails.
        :type: str
        """
        self._admin_password = admin_password

    @property
    def certificate(self):
        """
        Gets the certificate of this UpdateOggDeploymentDetails.
        A PEM-encoded SSL certificate.


        :return: The certificate of this UpdateOggDeploymentDetails.
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """
        Sets the certificate of this UpdateOggDeploymentDetails.
        A PEM-encoded SSL certificate.


        :param certificate: The certificate of this UpdateOggDeploymentDetails.
        :type: str
        """
        self._certificate = certificate

    @property
    def key(self):
        """
        Gets the key of this UpdateOggDeploymentDetails.
        A PEM-encoded private key.


        :return: The key of this UpdateOggDeploymentDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this UpdateOggDeploymentDetails.
        A PEM-encoded private key.


        :param key: The key of this UpdateOggDeploymentDetails.
        :type: str
        """
        self._key = key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .backoff_retry_policy import BackoffRetryPolicy
from .change_compartment_details import ChangeCompartmentDetails
from .confirmation_result import ConfirmationResult
from .create_subscription_details import CreateSubscriptionDetails
from .create_topic_details import CreateTopicDetails
from .delivery_policy import DeliveryPolicy
from .message_details import MessageDetails
from .notification_topic import NotificationTopic
from .notification_topic_summary import NotificationTopicSummary
from .publish_result import PublishResult
from .subscription import Subscription
from .subscription_summary import SubscriptionSummary
from .topic_attributes_details import TopicAttributesDetails
from .update_subscription_details import UpdateSubscriptionDetails

# Maps type names to classes for ons services.
ons_type_mapping = {
    "BackoffRetryPolicy": BackoffRetryPolicy,
    "ChangeCompartmentDetails": ChangeCompartmentDetails,
    "ConfirmationResult": ConfirmationResult,
    "CreateSubscriptionDetails": CreateSubscriptionDetails,
    "CreateTopicDetails": CreateTopicDetails,
    "DeliveryPolicy": DeliveryPolicy,
    "MessageDetails": MessageDetails,
    "NotificationTopic": NotificationTopic,
    "NotificationTopicSummary": NotificationTopicSummary,
    "PublishResult": PublishResult,
    "Subscription": Subscription,
    "SubscriptionSummary": SubscriptionSummary,
    "TopicAttributesDetails": TopicAttributesDetails,
    "UpdateSubscriptionDetails": UpdateSubscriptionDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsEntityType(object):
    """
    Description of log analytics entity type.
    """

    #: A constant which can be used with the cloud_type property of a LogAnalyticsEntityType.
    #: This constant has a value of "CLOUD"
    CLOUD_TYPE_CLOUD = "CLOUD"

    #: A constant which can be used with the cloud_type property of a LogAnalyticsEntityType.
    #: This constant has a value of "NON_CLOUD"
    CLOUD_TYPE_NON_CLOUD = "NON_CLOUD"

    #: A constant which can be used with the cloud_type property of a LogAnalyticsEntityType.
    #: This constant has a value of "ALL"
    CLOUD_TYPE_ALL = "ALL"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsEntityType.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsEntityType.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the management_agent_eligibility_status property of a LogAnalyticsEntityType.
    #: This constant has a value of "ELIGIBLE"
    MANAGEMENT_AGENT_ELIGIBILITY_STATUS_ELIGIBLE = "ELIGIBLE"

    #: A constant which can be used with the management_agent_eligibility_status property of a LogAnalyticsEntityType.
    #: This constant has a value of "INELIGIBLE"
    MANAGEMENT_AGENT_ELIGIBILITY_STATUS_INELIGIBLE = "INELIGIBLE"

    #: A constant which can be used with the management_agent_eligibility_status property of a LogAnalyticsEntityType.
    #: This constant has a value of "UNKNOWN"
    MANAGEMENT_AGENT_ELIGIBILITY_STATUS_UNKNOWN = "UNKNOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsEntityType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this LogAnalyticsEntityType.
        :type name: str

        :param internal_name:
            The value to assign to the internal_name property of this LogAnalyticsEntityType.
        :type internal_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsEntityType.
        :type compartment_id: str

        :param category:
            The value to assign to the category property of this LogAnalyticsEntityType.
        :type category: str

        :param cloud_type:
            The value to assign to the cloud_type property of this LogAnalyticsEntityType.
            Allowed values for this property are: "CLOUD", "NON_CLOUD", "ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type cloud_type: str

        :param properties:
            The value to assign to the properties property of this LogAnalyticsEntityType.
        :type properties: list[oci.log_analytics.models.EntityTypeProperty]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this LogAnalyticsEntityType.
            Allowed values for this property are: "ACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this LogAnalyticsEntityType.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this LogAnalyticsEntityType.
        :type time_updated: datetime

        :param management_agent_eligibility_status:
            The value to assign to the management_agent_eligibility_status property of this LogAnalyticsEntityType.
            Allowed values for this property are: "ELIGIBLE", "INELIGIBLE", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type management_agent_eligibility_status: str

        """
        self.swagger_types = {
            'name': 'str',
            'internal_name': 'str',
            'compartment_id': 'str',
            'category': 'str',
            'cloud_type': 'str',
            'properties': 'list[EntityTypeProperty]',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'management_agent_eligibility_status': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'internal_name': 'internalName',
            'compartment_id': 'compartmentId',
            'category': 'category',
            'cloud_type': 'cloudType',
            'properties': 'properties',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'management_agent_eligibility_status': 'managementAgentEligibilityStatus'
        }

        self._name = None
        self._internal_name = None
        self._compartment_id = None
        self._category = None
        self._cloud_type = None
        self._properties = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._management_agent_eligibility_status = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this LogAnalyticsEntityType.
        Log analytics entity type name.


        :return: The name of this LogAnalyticsEntityType.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsEntityType.
        Log analytics entity type name.


        :param name: The name of this LogAnalyticsEntityType.
        :type: str
        """
        self._name = name

    @property
    def internal_name(self):
        """
        **[Required]** Gets the internal_name of this LogAnalyticsEntityType.
        Internal name for the log analytics entity type.


        :return: The internal_name of this LogAnalyticsEntityType.
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """
        Sets the internal_name of this LogAnalyticsEntityType.
        Internal name for the log analytics entity type.


        :param internal_name: The internal_name of this LogAnalyticsEntityType.
        :type: str
        """
        self._internal_name = internal_name

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this LogAnalyticsEntityType.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this LogAnalyticsEntityType.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsEntityType.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this LogAnalyticsEntityType.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def category(self):
        """
        **[Required]** Gets the category of this LogAnalyticsEntityType.
        Log analytics entity type category. Category will be used for grouping and filtering.


        :return: The category of this LogAnalyticsEntityType.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this LogAnalyticsEntityType.
        Log analytics entity type category. Category will be used for grouping and filtering.


        :param category: The category of this LogAnalyticsEntityType.
        :type: str
        """
        self._category = category

    @property
    def cloud_type(self):
        """
        **[Required]** Gets the cloud_type of this LogAnalyticsEntityType.
        Log analytics entity type group. That can be CLOUD (OCI) or NON_CLOUD otherwise.

        Allowed values for this property are: "CLOUD", "NON_CLOUD", "ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The cloud_type of this LogAnalyticsEntityType.
        :rtype: str
        """
        return self._cloud_type

    @cloud_type.setter
    def cloud_type(self, cloud_type):
        """
        Sets the cloud_type of this LogAnalyticsEntityType.
        Log analytics entity type group. That can be CLOUD (OCI) or NON_CLOUD otherwise.


        :param cloud_type: The cloud_type of this LogAnalyticsEntityType.
        :type: str
        """
        allowed_values = ["CLOUD", "NON_CLOUD", "ALL"]
        if not value_allowed_none_or_none_sentinel(cloud_type, allowed_values):
            cloud_type = 'UNKNOWN_ENUM_VALUE'
        self._cloud_type = cloud_type

    @property
    def properties(self):
        """
        Gets the properties of this LogAnalyticsEntityType.
        The parameters used in file patterns specified in log sources for this log analytics entity type.


        :return: The properties of this LogAnalyticsEntityType.
        :rtype: list[oci.log_analytics.models.EntityTypeProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this LogAnalyticsEntityType.
        The parameters used in file patterns specified in log sources for this log analytics entity type.


        :param properties: The properties of this LogAnalyticsEntityType.
        :type: list[oci.log_analytics.models.EntityTypeProperty]
        """
        self._properties = properties

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this LogAnalyticsEntityType.
        The current lifecycle state of the log analytics entity.

        Allowed values for this property are: "ACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this LogAnalyticsEntityType.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this LogAnalyticsEntityType.
        The current lifecycle state of the log analytics entity.


        :param lifecycle_state: The lifecycle_state of this LogAnalyticsEntityType.
        :type: str
        """
        allowed_values = ["ACTIVE", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this LogAnalyticsEntityType.
        Time the log analytics entity type was created. An RFC3339 formatted datetime string.


        :return: The time_created of this LogAnalyticsEntityType.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this LogAnalyticsEntityType.
        Time the log analytics entity type was created. An RFC3339 formatted datetime string.


        :param time_created: The time_created of this LogAnalyticsEntityType.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this LogAnalyticsEntityType.
        Time the log analytics entity type was updated. An RFC3339 formatted datetime string.


        :return: The time_updated of this LogAnalyticsEntityType.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this LogAnalyticsEntityType.
        Time the log analytics entity type was updated. An RFC3339 formatted datetime string.


        :param time_updated: The time_updated of this LogAnalyticsEntityType.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def management_agent_eligibility_status(self):
        """
        Gets the management_agent_eligibility_status of this LogAnalyticsEntityType.
        This field indicates whether logs for entities of this type can be collected using a management agent.

        Allowed values for this property are: "ELIGIBLE", "INELIGIBLE", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The management_agent_eligibility_status of this LogAnalyticsEntityType.
        :rtype: str
        """
        return self._management_agent_eligibility_status

    @management_agent_eligibility_status.setter
    def management_agent_eligibility_status(self, management_agent_eligibility_status):
        """
        Sets the management_agent_eligibility_status of this LogAnalyticsEntityType.
        This field indicates whether logs for entities of this type can be collected using a management agent.


        :param management_agent_eligibility_status: The management_agent_eligibility_status of this LogAnalyticsEntityType.
        :type: str
        """
        allowed_values = ["ELIGIBLE", "INELIGIBLE", "UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(management_agent_eligibility_status, allowed_values):
            management_agent_eligibility_status = 'UNKNOWN_ENUM_VALUE'
        self._management_agent_eligibility_status = management_agent_eligibility_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryResultsOrderedBySummary(object):
    """
    Summary of the sort attribute and order by which the query results are organized.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryResultsOrderedBySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param query_results_ordered_by:
            The value to assign to the query_results_ordered_by property of this QueryResultsOrderedBySummary.
        :type query_results_ordered_by: str

        :param query_results_sort_order:
            The value to assign to the query_results_sort_order property of this QueryResultsOrderedBySummary.
        :type query_results_sort_order: str

        """
        self.swagger_types = {
            'query_results_ordered_by': 'str',
            'query_results_sort_order': 'str'
        }

        self.attribute_map = {
            'query_results_ordered_by': 'queryResultsOrderedBy',
            'query_results_sort_order': 'queryResultsSortOrder'
        }

        self._query_results_ordered_by = None
        self._query_results_sort_order = None

    @property
    def query_results_ordered_by(self):
        """
        Gets the query_results_ordered_by of this QueryResultsOrderedBySummary.
        Attribute by which the query result is sorted by.


        :return: The query_results_ordered_by of this QueryResultsOrderedBySummary.
        :rtype: str
        """
        return self._query_results_ordered_by

    @query_results_ordered_by.setter
    def query_results_ordered_by(self, query_results_ordered_by):
        """
        Sets the query_results_ordered_by of this QueryResultsOrderedBySummary.
        Attribute by which the query result is sorted by.


        :param query_results_ordered_by: The query_results_ordered_by of this QueryResultsOrderedBySummary.
        :type: str
        """
        self._query_results_ordered_by = query_results_ordered_by

    @property
    def query_results_sort_order(self):
        """
        Gets the query_results_sort_order of this QueryResultsOrderedBySummary.
        The sort order for the attribute, either 'ASC' or 'DESC'.


        :return: The query_results_sort_order of this QueryResultsOrderedBySummary.
        :rtype: str
        """
        return self._query_results_sort_order

    @query_results_sort_order.setter
    def query_results_sort_order(self, query_results_sort_order):
        """
        Sets the query_results_sort_order of this QueryResultsOrderedBySummary.
        The sort order for the attribute, either 'ASC' or 'DESC'.


        :param query_results_sort_order: The query_results_sort_order of this QueryResultsOrderedBySummary.
        :type: str
        """
        self._query_results_sort_order = query_results_sort_order

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .audit_event import AuditEvent
from .configuration import Configuration
from .data import Data
from .identity import Identity
from .request import Request
from .response import Response
from .state_change import StateChange
from .update_configuration_details import UpdateConfigurationDetails

# Maps type names to classes for audit services.
audit_type_mapping = {
    "AuditEvent": AuditEvent,
    "Configuration": Configuration,
    "Data": Data,
    "Identity": Identity,
    "Request": Request,
    "Response": Response,
    "StateChange": StateChange,
    "UpdateConfigurationDetails": UpdateConfigurationDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_connection_details import CreateConnectionDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateConnectionFromAmazonS3(CreateConnectionDetails):
    """
    The details to create a Amazon S3 connection.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateConnectionFromAmazonS3 object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.CreateConnectionFromAmazonS3.model_type` attribute
        of this class is ``AMAZON_S3_CONNECTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CreateConnectionFromAmazonS3.
            Allowed values for this property are: "ORACLE_ADWC_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLEDB_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION", "BICC_CONNECTION", "AMAZON_S3_CONNECTION"
        :type model_type: str

        :param key:
            The value to assign to the key property of this CreateConnectionFromAmazonS3.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateConnectionFromAmazonS3.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this CreateConnectionFromAmazonS3.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this CreateConnectionFromAmazonS3.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateConnectionFromAmazonS3.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this CreateConnectionFromAmazonS3.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateConnectionFromAmazonS3.
        :type identifier: str

        :param connection_properties:
            The value to assign to the connection_properties property of this CreateConnectionFromAmazonS3.
        :type connection_properties: list[oci.data_integration.models.ConnectionProperty]

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateConnectionFromAmazonS3.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        :param access_key:
            The value to assign to the access_key property of this CreateConnectionFromAmazonS3.
        :type access_key: oci.data_integration.models.SensitiveAttribute

        :param secret_key:
            The value to assign to the secret_key property of this CreateConnectionFromAmazonS3.
        :type secret_key: oci.data_integration.models.SensitiveAttribute

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'connection_properties': 'list[ConnectionProperty]',
            'registry_metadata': 'RegistryMetadata',
            'access_key': 'SensitiveAttribute',
            'secret_key': 'SensitiveAttribute'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'connection_properties': 'connectionProperties',
            'registry_metadata': 'registryMetadata',
            'access_key': 'accessKey',
            'secret_key': 'secretKey'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._connection_properties = None
        self._registry_metadata = None
        self._access_key = None
        self._secret_key = None
        self._model_type = 'AMAZON_S3_CONNECTION'

    @property
    def access_key(self):
        """
        Gets the access_key of this CreateConnectionFromAmazonS3.

        :return: The access_key of this CreateConnectionFromAmazonS3.
        :rtype: oci.data_integration.models.SensitiveAttribute
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """
        Sets the access_key of this CreateConnectionFromAmazonS3.

        :param access_key: The access_key of this CreateConnectionFromAmazonS3.
        :type: oci.data_integration.models.SensitiveAttribute
        """
        self._access_key = access_key

    @property
    def secret_key(self):
        """
        Gets the secret_key of this CreateConnectionFromAmazonS3.

        :return: The secret_key of this CreateConnectionFromAmazonS3.
        :rtype: oci.data_integration.models.SensitiveAttribute
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        """
        Sets the secret_key of this CreateConnectionFromAmazonS3.

        :param secret_key: The secret_key of this CreateConnectionFromAmazonS3.
        :type: oci.data_integration.models.SensitiveAttribute
        """
        self._secret_key = secret_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2018 Kenneth Reitz

#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
requests.certs
~~~~~~~~~~~~~~

This module returns the preferred default CA certificate bundle. There is
only one — the one from the certifi package.

If you are packaging Requests, e.g., for a Linux distribution or a managed
environment, you can change the definition of where() to return a separately
packaged CA bundle.
"""
from certifi import where

if __name__ == '__main__':
    print(where())



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDomainGovernanceDetails(object):
    """
    The parameters for updating a domain govenance entity.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDomainGovernanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param subscription_email:
            The value to assign to the subscription_email property of this UpdateDomainGovernanceDetails.
        :type subscription_email: str

        :param is_governance_enabled:
            The value to assign to the is_governance_enabled property of this UpdateDomainGovernanceDetails.
        :type is_governance_enabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDomainGovernanceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDomainGovernanceDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'subscription_email': 'str',
            'is_governance_enabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'subscription_email': 'subscriptionEmail',
            'is_governance_enabled': 'isGovernanceEnabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._subscription_email = None
        self._is_governance_enabled = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def subscription_email(self):
        """
        Gets the subscription_email of this UpdateDomainGovernanceDetails.
        The email to notify the user, and that the ONS subscription will be created with. The ONS subscription for the previous email will also be deleted.


        :return: The subscription_email of this UpdateDomainGovernanceDetails.
        :rtype: str
        """
        return self._subscription_email

    @subscription_email.setter
    def subscription_email(self, subscription_email):
        """
        Sets the subscription_email of this UpdateDomainGovernanceDetails.
        The email to notify the user, and that the ONS subscription will be created with. The ONS subscription for the previous email will also be deleted.


        :param subscription_email: The subscription_email of this UpdateDomainGovernanceDetails.
        :type: str
        """
        self._subscription_email = subscription_email

    @property
    def is_governance_enabled(self):
        """
        Gets the is_governance_enabled of this UpdateDomainGovernanceDetails.
        Indicates whether governance is enabled for this domain.


        :return: The is_governance_enabled of this UpdateDomainGovernanceDetails.
        :rtype: bool
        """
        return self._is_governance_enabled

    @is_governance_enabled.setter
    def is_governance_enabled(self, is_governance_enabled):
        """
        Sets the is_governance_enabled of this UpdateDomainGovernanceDetails.
        Indicates whether governance is enabled for this domain.


        :param is_governance_enabled: The is_governance_enabled of this UpdateDomainGovernanceDetails.
        :type: bool
        """
        self._is_governance_enabled = is_governance_enabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateDomainGovernanceDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateDomainGovernanceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateDomainGovernanceDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateDomainGovernanceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateDomainGovernanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateDomainGovernanceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateDomainGovernanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateDomainGovernanceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDkimDetails(object):
    """
    Properties to create a new DKIM.
    The new object will be created in the same compartment as the EmailDomain.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDkimDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateDkimDetails.
        :type name: str

        :param email_domain_id:
            The value to assign to the email_domain_id property of this CreateDkimDetails.
        :type email_domain_id: str

        :param description:
            The value to assign to the description property of this CreateDkimDetails.
        :type description: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDkimDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDkimDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'name': 'str',
            'email_domain_id': 'str',
            'description': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'name': 'name',
            'email_domain_id': 'emailDomainId',
            'description': 'description',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._name = None
        self._email_domain_id = None
        self._description = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def name(self):
        """
        Gets the name of this CreateDkimDetails.
        The DKIM selector. This selector is required to be globally unique for this email domain.
        If you do not provide the selector, we will generate one for you.
        If you do provide the selector, we suggest adding a short region indicator
        to differentiate from your signing of emails in other regions you may be subscribed to.
        Selectors limited to ASCII characters may use alphanumeric, dash (\"-\"), and dot (\".\") characters.
        Non-ASCII selector names should adopt IDNA2008 normalization (RFC 5891-5892).

        Avoid entering confidential information.

        Example: `mydomain-phx-20210228`


        :return: The name of this CreateDkimDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateDkimDetails.
        The DKIM selector. This selector is required to be globally unique for this email domain.
        If you do not provide the selector, we will generate one for you.
        If you do provide the selector, we suggest adding a short region indicator
        to differentiate from your signing of emails in other regions you may be subscribed to.
        Selectors limited to ASCII characters may use alphanumeric, dash (\"-\"), and dot (\".\") characters.
        Non-ASCII selector names should adopt IDNA2008 normalization (RFC 5891-5892).

        Avoid entering confidential information.

        Example: `mydomain-phx-20210228`


        :param name: The name of this CreateDkimDetails.
        :type: str
        """
        self._name = name

    @property
    def email_domain_id(self):
        """
        **[Required]** Gets the email_domain_id of this CreateDkimDetails.
        The `OCID`__ of the EmailDomain for this DKIM.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The email_domain_id of this CreateDkimDetails.
        :rtype: str
        """
        return self._email_domain_id

    @email_domain_id.setter
    def email_domain_id(self, email_domain_id):
        """
        Sets the email_domain_id of this CreateDkimDetails.
        The `OCID`__ of the EmailDomain for this DKIM.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param email_domain_id: The email_domain_id of this CreateDkimDetails.
        :type: str
        """
        self._email_domain_id = email_domain_id

    @property
    def description(self):
        """
        Gets the description of this CreateDkimDetails.
        A string that describes the details about the DKIM. It does not have to be unique,
        and you can change it. Avoid entering confidential information.


        :return: The description of this CreateDkimDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDkimDetails.
        A string that describes the details about the DKIM. It does not have to be unique,
        and you can change it. Avoid entering confidential information.


        :param description: The description of this CreateDkimDetails.
        :type: str
        """
        self._description = description

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDkimDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateDkimDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDkimDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateDkimDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDkimDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateDkimDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDkimDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateDkimDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostVulnerabilityImpactedHostSummary(object):
    """
    Information on a host impacted by a vulnerability
    """

    #: A constant which can be used with the lifecycle_state property of a HostVulnerabilityImpactedHostSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a HostVulnerabilityImpactedHostSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a HostVulnerabilityImpactedHostSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a HostVulnerabilityImpactedHostSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a HostVulnerabilityImpactedHostSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a HostVulnerabilityImpactedHostSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new HostVulnerabilityImpactedHostSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_id:
            The value to assign to the instance_id property of this HostVulnerabilityImpactedHostSummary.
        :type instance_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this HostVulnerabilityImpactedHostSummary.
        :type compartment_id: str

        :param last_agent_scan_id:
            The value to assign to the last_agent_scan_id property of this HostVulnerabilityImpactedHostSummary.
        :type last_agent_scan_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this HostVulnerabilityImpactedHostSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'instance_id': 'str',
            'compartment_id': 'str',
            'last_agent_scan_id': 'str',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'instance_id': 'instanceId',
            'compartment_id': 'compartmentId',
            'last_agent_scan_id': 'lastAgentScanId',
            'lifecycle_state': 'lifecycleState'
        }

        self._instance_id = None
        self._compartment_id = None
        self._last_agent_scan_id = None
        self._lifecycle_state = None

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this HostVulnerabilityImpactedHostSummary.
        The compute instance ID of the impacted host


        :return: The instance_id of this HostVulnerabilityImpactedHostSummary.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this HostVulnerabilityImpactedHostSummary.
        The compute instance ID of the impacted host


        :param instance_id: The instance_id of this HostVulnerabilityImpactedHostSummary.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this HostVulnerabilityImpactedHostSummary.
        The compartment ID of the impacted host


        :return: The compartment_id of this HostVulnerabilityImpactedHostSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this HostVulnerabilityImpactedHostSummary.
        The compartment ID of the impacted host


        :param compartment_id: The compartment_id of this HostVulnerabilityImpactedHostSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def last_agent_scan_id(self):
        """
        **[Required]** Gets the last_agent_scan_id of this HostVulnerabilityImpactedHostSummary.
        The ID of the last host agent scan result


        :return: The last_agent_scan_id of this HostVulnerabilityImpactedHostSummary.
        :rtype: str
        """
        return self._last_agent_scan_id

    @last_agent_scan_id.setter
    def last_agent_scan_id(self, last_agent_scan_id):
        """
        Sets the last_agent_scan_id of this HostVulnerabilityImpactedHostSummary.
        The ID of the last host agent scan result


        :param last_agent_scan_id: The last_agent_scan_id of this HostVulnerabilityImpactedHostSummary.
        :type: str
        """
        self._last_agent_scan_id = last_agent_scan_id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this HostVulnerabilityImpactedHostSummary.
        The current state of the resource.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this HostVulnerabilityImpactedHostSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this HostVulnerabilityImpactedHostSummary.
        The current state of the resource.


        :param lifecycle_state: The lifecycle_state of this HostVulnerabilityImpactedHostSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class AnomalyDetectionClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.ai_anomaly_detection.AnomalyDetectionClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new AnomalyDetectionClientCompositeOperations object

        :param AnomalyDetectionClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def change_ai_private_endpoint_compartment_and_wait_for_state(self, ai_private_endpoint_id, change_ai_private_endpoint_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.change_ai_private_endpoint_compartment` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param str ai_private_endpoint_id: (required)
            Unique private reverse connection identifier.

        :param oci.ai_anomaly_detection.models.ChangeAiPrivateEndpointCompartmentDetails change_ai_private_endpoint_compartment_details: (required)
            Details for the target compartment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.change_ai_private_endpoint_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_ai_private_endpoint_compartment(ai_private_endpoint_id, change_ai_private_endpoint_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def change_data_asset_compartment_and_wait_for_state(self, data_asset_id, change_data_asset_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.change_data_asset_compartment` and waits for the :py:class:`~oci.ai_anomaly_detection.models.DataAsset` acted upon
        to enter the given state(s).

        :param str data_asset_id: (required)
            The OCID of the Data Asset.

        :param oci.ai_anomaly_detection.models.ChangeDataAssetCompartmentDetails change_data_asset_compartment_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.DataAsset.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.change_data_asset_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_data_asset_compartment(data_asset_id, change_data_asset_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_data_asset(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_ai_private_endpoint_and_wait_for_state(self, create_ai_private_endpoint_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_ai_private_endpoint` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_anomaly_detection.models.CreateAiPrivateEndpointDetails create_ai_private_endpoint_details: (required)
            The information used to create the private reverse connection.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_ai_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_ai_private_endpoint(create_ai_private_endpoint_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_data_asset_and_wait_for_state(self, create_data_asset_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_data_asset` and waits for the :py:class:`~oci.ai_anomaly_detection.models.DataAsset` acted upon
        to enter the given state(s).

        :param oci.ai_anomaly_detection.models.CreateDataAssetDetails create_data_asset_details: (required)
            Details for the new DataAsset.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.DataAsset.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_data_asset`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_data_asset(create_data_asset_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_data_asset(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_model_and_wait_for_state(self, create_model_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_model` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_anomaly_detection.models.CreateModelDetails create_model_details: (required)
            Details for the new Model.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_model`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_model(create_model_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_project_and_wait_for_state(self, create_project_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_project` and waits for the :py:class:`~oci.ai_anomaly_detection.models.Project` acted upon
        to enter the given state(s).

        :param oci.ai_anomaly_detection.models.CreateProjectDetails create_project_details: (required)
            Details for the new Project.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.Project.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.create_project`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_project(create_project_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_project(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_ai_private_endpoint_and_wait_for_state(self, ai_private_endpoint_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_ai_private_endpoint` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param str ai_private_endpoint_id: (required)
            Unique private reverse connection identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_ai_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_ai_private_endpoint(ai_private_endpoint_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_data_asset_and_wait_for_state(self, data_asset_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_data_asset` and waits for the :py:class:`~oci.ai_anomaly_detection.models.DataAsset` acted upon
        to enter the given state(s).

        :param str data_asset_id: (required)
            The OCID of the Data Asset.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.DataAsset.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_data_asset`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_data_asset(data_asset_id)
        operation_result = None
        try:
            operation_result = self.client.delete_data_asset(data_asset_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_model_and_wait_for_state(self, model_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_model` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param str model_id: (required)
            The OCID of the Model.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_model`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_model(model_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_project_and_wait_for_state(self, project_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_project` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param str project_id: (required)
            The OCID of the Project.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.delete_project`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_project(project_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_ai_private_endpoint_and_wait_for_state(self, ai_private_endpoint_id, update_ai_private_endpoint_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_ai_private_endpoint` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param str ai_private_endpoint_id: (required)
            Unique private reverse connection identifier.

        :param oci.ai_anomaly_detection.models.UpdateAiPrivateEndpointDetails update_ai_private_endpoint_details: (required)
            The information to be updated in private reverse connection

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_ai_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_ai_private_endpoint(ai_private_endpoint_id, update_ai_private_endpoint_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_data_asset_and_wait_for_state(self, data_asset_id, update_data_asset_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_data_asset` and waits for the :py:class:`~oci.ai_anomaly_detection.models.DataAsset` acted upon
        to enter the given state(s).

        :param str data_asset_id: (required)
            The OCID of the Data Asset.

        :param oci.ai_anomaly_detection.models.UpdateDataAssetDetails update_data_asset_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.DataAsset.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_data_asset`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_data_asset(data_asset_id, update_data_asset_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_data_asset(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_model_and_wait_for_state(self, model_id, update_model_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_model` and waits for the :py:class:`~oci.ai_anomaly_detection.models.WorkRequest`
        to enter the given state(s).

        :param str model_id: (required)
            The OCID of the Model.

        :param oci.ai_anomaly_detection.models.UpdateModelDetails update_model_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_model`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_model(model_id, update_model_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_project_and_wait_for_state(self, project_id, update_project_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_project` and waits for the :py:class:`~oci.ai_anomaly_detection.models.Project` acted upon
        to enter the given state(s).

        :param str project_id: (required)
            The OCID of the Project.

        :param oci.ai_anomaly_detection.models.UpdateProjectDetails update_project_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_anomaly_detection.models.Project.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_anomaly_detection.AnomalyDetectionClient.update_project`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_project(project_id, update_project_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_project(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseBackupConfig(object):
    """
    Autonomous Database configuration details for storing `manual backups`__ in the `Object Storage`__ service.

    __ https://docs.cloud.oracle.com/Content/Database/Tasks/adbbackingup.htm
    __ https://docs.cloud.oracle.com/Content/Object/Concepts/objectstorageoverview.htm
    """

    #: A constant which can be used with the manual_backup_type property of a AutonomousDatabaseBackupConfig.
    #: This constant has a value of "NONE"
    MANUAL_BACKUP_TYPE_NONE = "NONE"

    #: A constant which can be used with the manual_backup_type property of a AutonomousDatabaseBackupConfig.
    #: This constant has a value of "OBJECT_STORE"
    MANUAL_BACKUP_TYPE_OBJECT_STORE = "OBJECT_STORE"

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseBackupConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param manual_backup_bucket_name:
            The value to assign to the manual_backup_bucket_name property of this AutonomousDatabaseBackupConfig.
        :type manual_backup_bucket_name: str

        :param manual_backup_type:
            The value to assign to the manual_backup_type property of this AutonomousDatabaseBackupConfig.
            Allowed values for this property are: "NONE", "OBJECT_STORE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type manual_backup_type: str

        """
        self.swagger_types = {
            'manual_backup_bucket_name': 'str',
            'manual_backup_type': 'str'
        }

        self.attribute_map = {
            'manual_backup_bucket_name': 'manualBackupBucketName',
            'manual_backup_type': 'manualBackupType'
        }

        self._manual_backup_bucket_name = None
        self._manual_backup_type = None

    @property
    def manual_backup_bucket_name(self):
        """
        Gets the manual_backup_bucket_name of this AutonomousDatabaseBackupConfig.
        Name of `Object Storage`__ bucket to use for storing manual backups.

        __ https://docs.cloud.oracle.com/Content/Object/Concepts/objectstorageoverview.htm


        :return: The manual_backup_bucket_name of this AutonomousDatabaseBackupConfig.
        :rtype: str
        """
        return self._manual_backup_bucket_name

    @manual_backup_bucket_name.setter
    def manual_backup_bucket_name(self, manual_backup_bucket_name):
        """
        Sets the manual_backup_bucket_name of this AutonomousDatabaseBackupConfig.
        Name of `Object Storage`__ bucket to use for storing manual backups.

        __ https://docs.cloud.oracle.com/Content/Object/Concepts/objectstorageoverview.htm


        :param manual_backup_bucket_name: The manual_backup_bucket_name of this AutonomousDatabaseBackupConfig.
        :type: str
        """
        self._manual_backup_bucket_name = manual_backup_bucket_name

    @property
    def manual_backup_type(self):
        """
        Gets the manual_backup_type of this AutonomousDatabaseBackupConfig.
        The manual backup destination type.

        Allowed values for this property are: "NONE", "OBJECT_STORE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The manual_backup_type of this AutonomousDatabaseBackupConfig.
        :rtype: str
        """
        return self._manual_backup_type

    @manual_backup_type.setter
    def manual_backup_type(self, manual_backup_type):
        """
        Sets the manual_backup_type of this AutonomousDatabaseBackupConfig.
        The manual backup destination type.


        :param manual_backup_type: The manual_backup_type of this AutonomousDatabaseBackupConfig.
        :type: str
        """
        allowed_values = ["NONE", "OBJECT_STORE"]
        if not value_allowed_none_or_none_sentinel(manual_backup_type, allowed_values):
            manual_backup_type = 'UNKNOWN_ENUM_VALUE'
        self._manual_backup_type = manual_backup_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_config_source_details import UpdateConfigSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateZipUploadConfigSourceDetails(UpdateConfigSourceDetails):
    """
    Updates property details for the configuration .zip file.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateZipUploadConfigSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.resource_manager.models.UpdateZipUploadConfigSourceDetails.config_source_type` attribute
        of this class is ``ZIP_UPLOAD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_source_type:
            The value to assign to the config_source_type property of this UpdateZipUploadConfigSourceDetails.
        :type config_source_type: str

        :param working_directory:
            The value to assign to the working_directory property of this UpdateZipUploadConfigSourceDetails.
        :type working_directory: str

        :param zip_file_base64_encoded:
            The value to assign to the zip_file_base64_encoded property of this UpdateZipUploadConfigSourceDetails.
        :type zip_file_base64_encoded: str

        """
        self.swagger_types = {
            'config_source_type': 'str',
            'working_directory': 'str',
            'zip_file_base64_encoded': 'str'
        }

        self.attribute_map = {
            'config_source_type': 'configSourceType',
            'working_directory': 'workingDirectory',
            'zip_file_base64_encoded': 'zipFileBase64Encoded'
        }

        self._config_source_type = None
        self._working_directory = None
        self._zip_file_base64_encoded = None
        self._config_source_type = 'ZIP_UPLOAD'

    @property
    def zip_file_base64_encoded(self):
        """
        Gets the zip_file_base64_encoded of this UpdateZipUploadConfigSourceDetails.

        :return: The zip_file_base64_encoded of this UpdateZipUploadConfigSourceDetails.
        :rtype: str
        """
        return self._zip_file_base64_encoded

    @zip_file_base64_encoded.setter
    def zip_file_base64_encoded(self, zip_file_base64_encoded):
        """
        Sets the zip_file_base64_encoded of this UpdateZipUploadConfigSourceDetails.

        :param zip_file_base64_encoded: The zip_file_base64_encoded of this UpdateZipUploadConfigSourceDetails.
        :type: str
        """
        self._zip_file_base64_encoded = zip_file_base64_encoded

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .base_announcement import BaseAnnouncement
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnnouncementSummary(BaseAnnouncement):
    """
    A summary representation of an announcement.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnnouncementSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.announcements_service.models.AnnouncementSummary.type` attribute
        of this class is ``AnnouncementSummary`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AnnouncementSummary.
        :type id: str

        :param type:
            The value to assign to the type property of this AnnouncementSummary.
        :type type: str

        :param reference_ticket_number:
            The value to assign to the reference_ticket_number property of this AnnouncementSummary.
        :type reference_ticket_number: str

        :param summary:
            The value to assign to the summary property of this AnnouncementSummary.
        :type summary: str

        :param time_one_title:
            The value to assign to the time_one_title property of this AnnouncementSummary.
        :type time_one_title: str

        :param time_one_type:
            The value to assign to the time_one_type property of this AnnouncementSummary.
            Allowed values for this property are: "ACTION_REQUIRED_BY", "NEW_START_TIME", "ORIGINAL_END_TIME", "REPORT_DATE", "START_TIME", "TIME_DETECTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type time_one_type: str

        :param time_one_value:
            The value to assign to the time_one_value property of this AnnouncementSummary.
        :type time_one_value: datetime

        :param time_two_title:
            The value to assign to the time_two_title property of this AnnouncementSummary.
        :type time_two_title: str

        :param time_two_type:
            The value to assign to the time_two_type property of this AnnouncementSummary.
            Allowed values for this property are: "END_TIME", "NEW_END_TIME", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type time_two_type: str

        :param time_two_value:
            The value to assign to the time_two_value property of this AnnouncementSummary.
        :type time_two_value: datetime

        :param services:
            The value to assign to the services property of this AnnouncementSummary.
        :type services: list[str]

        :param affected_regions:
            The value to assign to the affected_regions property of this AnnouncementSummary.
        :type affected_regions: list[str]

        :param announcement_type:
            The value to assign to the announcement_type property of this AnnouncementSummary.
            Allowed values for this property are: "ACTION_RECOMMENDED", "ACTION_REQUIRED", "EMERGENCY_CHANGE", "EMERGENCY_MAINTENANCE", "EMERGENCY_MAINTENANCE_COMPLETE", "EMERGENCY_MAINTENANCE_EXTENDED", "EMERGENCY_MAINTENANCE_RESCHEDULED", "INFORMATION", "PLANNED_CHANGE", "PLANNED_CHANGE_COMPLETE", "PLANNED_CHANGE_EXTENDED", "PLANNED_CHANGE_RESCHEDULED", "PRODUCTION_EVENT_NOTIFICATION", "SCHEDULED_MAINTENANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type announcement_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AnnouncementSummary.
            Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param is_banner:
            The value to assign to the is_banner property of this AnnouncementSummary.
        :type is_banner: bool

        :param time_created:
            The value to assign to the time_created property of this AnnouncementSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AnnouncementSummary.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'type': 'str',
            'reference_ticket_number': 'str',
            'summary': 'str',
            'time_one_title': 'str',
            'time_one_type': 'str',
            'time_one_value': 'datetime',
            'time_two_title': 'str',
            'time_two_type': 'str',
            'time_two_value': 'datetime',
            'services': 'list[str]',
            'affected_regions': 'list[str]',
            'announcement_type': 'str',
            'lifecycle_state': 'str',
            'is_banner': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'type': 'type',
            'reference_ticket_number': 'referenceTicketNumber',
            'summary': 'summary',
            'time_one_title': 'timeOneTitle',
            'time_one_type': 'timeOneType',
            'time_one_value': 'timeOneValue',
            'time_two_title': 'timeTwoTitle',
            'time_two_type': 'timeTwoType',
            'time_two_value': 'timeTwoValue',
            'services': 'services',
            'affected_regions': 'affectedRegions',
            'announcement_type': 'announcementType',
            'lifecycle_state': 'lifecycleState',
            'is_banner': 'isBanner',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._type = None
        self._reference_ticket_number = None
        self._summary = None
        self._time_one_title = None
        self._time_one_type = None
        self._time_one_value = None
        self._time_two_title = None
        self._time_two_type = None
        self._time_two_value = None
        self._services = None
        self._affected_regions = None
        self._announcement_type = None
        self._lifecycle_state = None
        self._is_banner = None
        self._time_created = None
        self._time_updated = None
        self._type = 'AnnouncementSummary'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FlexComponentSummary(object):
    """
    The Flex Components for a DB system. The Flex Component determines resources to allocate to the DB system -  CPU cores, memory and storage for Flex shapes.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator.
    If you're an administrator who needs to write policies to give users access,
    see `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FlexComponentSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this FlexComponentSummary.
        :type name: str

        :param minimum_core_count:
            The value to assign to the minimum_core_count property of this FlexComponentSummary.
        :type minimum_core_count: int

        :param available_core_count:
            The value to assign to the available_core_count property of this FlexComponentSummary.
        :type available_core_count: int

        :param available_db_storage_in_gbs:
            The value to assign to the available_db_storage_in_gbs property of this FlexComponentSummary.
        :type available_db_storage_in_gbs: int

        """
        self.swagger_types = {
            'name': 'str',
            'minimum_core_count': 'int',
            'available_core_count': 'int',
            'available_db_storage_in_gbs': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'minimum_core_count': 'minimumCoreCount',
            'available_core_count': 'availableCoreCount',
            'available_db_storage_in_gbs': 'availableDbStorageInGBs'
        }

        self._name = None
        self._minimum_core_count = None
        self._available_core_count = None
        self._available_db_storage_in_gbs = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this FlexComponentSummary.
        The name of the Flex Component used for the DB system.


        :return: The name of this FlexComponentSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlexComponentSummary.
        The name of the Flex Component used for the DB system.


        :param name: The name of this FlexComponentSummary.
        :type: str
        """
        self._name = name

    @property
    def minimum_core_count(self):
        """
        Gets the minimum_core_count of this FlexComponentSummary.
        The minimum number of CPU cores that can be enabled on the DB Server for this Flex Component.


        :return: The minimum_core_count of this FlexComponentSummary.
        :rtype: int
        """
        return self._minimum_core_count

    @minimum_core_count.setter
    def minimum_core_count(self, minimum_core_count):
        """
        Sets the minimum_core_count of this FlexComponentSummary.
        The minimum number of CPU cores that can be enabled on the DB Server for this Flex Component.


        :param minimum_core_count: The minimum_core_count of this FlexComponentSummary.
        :type: int
        """
        self._minimum_core_count = minimum_core_count

    @property
    def available_core_count(self):
        """
        Gets the available_core_count of this FlexComponentSummary.
        The maximum number of CPU cores that can ben enabled on the DB Server for this Flex Component.


        :return: The available_core_count of this FlexComponentSummary.
        :rtype: int
        """
        return self._available_core_count

    @available_core_count.setter
    def available_core_count(self, available_core_count):
        """
        Sets the available_core_count of this FlexComponentSummary.
        The maximum number of CPU cores that can ben enabled on the DB Server for this Flex Component.


        :param available_core_count: The available_core_count of this FlexComponentSummary.
        :type: int
        """
        self._available_core_count = available_core_count

    @property
    def available_db_storage_in_gbs(self):
        """
        Gets the available_db_storage_in_gbs of this FlexComponentSummary.
        The maximum  storage that can be enabled on the Storage Server for this Flex Component.


        :return: The available_db_storage_in_gbs of this FlexComponentSummary.
        :rtype: int
        """
        return self._available_db_storage_in_gbs

    @available_db_storage_in_gbs.setter
    def available_db_storage_in_gbs(self, available_db_storage_in_gbs):
        """
        Sets the available_db_storage_in_gbs of this FlexComponentSummary.
        The maximum  storage that can be enabled on the Storage Server for this Flex Component.


        :param available_db_storage_in_gbs: The available_db_storage_in_gbs of this FlexComponentSummary.
        :type: int
        """
        self._available_db_storage_in_gbs = available_db_storage_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FacetedSearchStringFilterRequest(object):
    """
    Object with string filter criteria
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FacetedSearchStringFilterRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param field:
            The value to assign to the field property of this FacetedSearchStringFilterRequest.
        :type field: str

        :param values:
            The value to assign to the values property of this FacetedSearchStringFilterRequest.
        :type values: list[str]

        """
        self.swagger_types = {
            'field': 'str',
            'values': 'list[str]'
        }

        self.attribute_map = {
            'field': 'field',
            'values': 'values'
        }

        self._field = None
        self._values = None

    @property
    def field(self):
        """
        Gets the field of this FacetedSearchStringFilterRequest.
        String/boolean/numerical field name that needs to filtered with


        :return: The field of this FacetedSearchStringFilterRequest.
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """
        Sets the field of this FacetedSearchStringFilterRequest.
        String/boolean/numerical field name that needs to filtered with


        :param field: The field of this FacetedSearchStringFilterRequest.
        :type: str
        """
        self._field = field

    @property
    def values(self):
        """
        Gets the values of this FacetedSearchStringFilterRequest.
        Array of values that the search results needs to be filtered by.


        :return: The values of this FacetedSearchStringFilterRequest.
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this FacetedSearchStringFilterRequest.
        Array of values that the search results needs to be filtered by.


        :param values: The values of this FacetedSearchStringFilterRequest.
        :type: list[str]
        """
        self._values = values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateInstanceAgentCommandDetails(object):
    """
    Creation details for an Oracle Cloud Agent command.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateInstanceAgentCommandDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateInstanceAgentCommandDetails.
        :type compartment_id: str

        :param execution_time_out_in_seconds:
            The value to assign to the execution_time_out_in_seconds property of this CreateInstanceAgentCommandDetails.
        :type execution_time_out_in_seconds: int

        :param display_name:
            The value to assign to the display_name property of this CreateInstanceAgentCommandDetails.
        :type display_name: str

        :param target:
            The value to assign to the target property of this CreateInstanceAgentCommandDetails.
        :type target: oci.compute_instance_agent.models.InstanceAgentCommandTarget

        :param content:
            The value to assign to the content property of this CreateInstanceAgentCommandDetails.
        :type content: oci.compute_instance_agent.models.InstanceAgentCommandContent

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'execution_time_out_in_seconds': 'int',
            'display_name': 'str',
            'target': 'InstanceAgentCommandTarget',
            'content': 'InstanceAgentCommandContent'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'execution_time_out_in_seconds': 'executionTimeOutInSeconds',
            'display_name': 'displayName',
            'target': 'target',
            'content': 'content'
        }

        self._compartment_id = None
        self._execution_time_out_in_seconds = None
        self._display_name = None
        self._target = None
        self._content = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateInstanceAgentCommandDetails.
        The `OCID`__ of the compartment to create the command in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateInstanceAgentCommandDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateInstanceAgentCommandDetails.
        The `OCID`__ of the compartment to create the command in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateInstanceAgentCommandDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def execution_time_out_in_seconds(self):
        """
        **[Required]** Gets the execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        The amount of time that Oracle Cloud Agent is given to run the command on the instance before timing
        out. The timer starts when Oracle Cloud Agent starts the command. Zero means no timeout.


        :return: The execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        :rtype: int
        """
        return self._execution_time_out_in_seconds

    @execution_time_out_in_seconds.setter
    def execution_time_out_in_seconds(self, execution_time_out_in_seconds):
        """
        Sets the execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        The amount of time that Oracle Cloud Agent is given to run the command on the instance before timing
        out. The timer starts when Oracle Cloud Agent starts the command. Zero means no timeout.


        :param execution_time_out_in_seconds: The execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        :type: int
        """
        self._execution_time_out_in_seconds = execution_time_out_in_seconds

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateInstanceAgentCommandDetails.
        A user-friendly name for the command. It does not have to be unique.
        Avoid entering confidential information.

        Example: `Database Backup Script`


        :return: The display_name of this CreateInstanceAgentCommandDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateInstanceAgentCommandDetails.
        A user-friendly name for the command. It does not have to be unique.
        Avoid entering confidential information.

        Example: `Database Backup Script`


        :param display_name: The display_name of this CreateInstanceAgentCommandDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def target(self):
        """
        **[Required]** Gets the target of this CreateInstanceAgentCommandDetails.
        The target instance to run the command on.


        :return: The target of this CreateInstanceAgentCommandDetails.
        :rtype: oci.compute_instance_agent.models.InstanceAgentCommandTarget
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this CreateInstanceAgentCommandDetails.
        The target instance to run the command on.


        :param target: The target of this CreateInstanceAgentCommandDetails.
        :type: oci.compute_instance_agent.models.InstanceAgentCommandTarget
        """
        self._target = target

    @property
    def content(self):
        """
        **[Required]** Gets the content of this CreateInstanceAgentCommandDetails.
        The contents of the command.


        :return: The content of this CreateInstanceAgentCommandDetails.
        :rtype: oci.compute_instance_agent.models.InstanceAgentCommandContent
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this CreateInstanceAgentCommandDetails.
        The contents of the command.


        :param content: The content of this CreateInstanceAgentCommandDetails.
        :type: oci.compute_instance_agent.models.InstanceAgentCommandContent
        """
        self._content = content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateOnPremConnectorConfigurationDetails(object):
    """
    The details used to create and download on-premises connector's configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateOnPremConnectorConfigurationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param password:
            The value to assign to the password property of this GenerateOnPremConnectorConfigurationDetails.
        :type password: str

        """
        self.swagger_types = {
            'password': 'str'
        }

        self.attribute_map = {
            'password': 'password'
        }

        self._password = None

    @property
    def password(self):
        """
        **[Required]** Gets the password of this GenerateOnPremConnectorConfigurationDetails.
        The password to encrypt the keys inside the wallet included as part of the configuration. The password must be between 12 and 30 characters long and must contain atleast 1 uppercase, 1 lowercase, 1 numeric, and 1 special character.


        :return: The password of this GenerateOnPremConnectorConfigurationDetails.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this GenerateOnPremConnectorConfigurationDetails.
        The password to encrypt the keys inside the wallet included as part of the configuration. The password must be between 12 and 30 characters long and must contain atleast 1 uppercase, 1 lowercase, 1 numeric, and 1 special character.


        :param password: The password of this GenerateOnPremConnectorConfigurationDetails.
        :type: str
        """
        self._password = password

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_configuration_metric_group import HostConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostCpuHardwareConfiguration(HostConfigurationMetricGroup):
    """
    CPU Hardware Configuration metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostCpuHardwareConfiguration object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostCpuHardwareConfiguration.metric_name` attribute
        of this class is ``HOST_CPU_HARDWARE_CONFIGURATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostCpuHardwareConfiguration.
            Allowed values for this property are: "HOST_PRODUCT", "HOST_RESOURCE_ALLOCATION", "HOST_MEMORY_CONFIGURATION", "HOST_HARDWARE_CONFIGURATION", "HOST_CPU_HARDWARE_CONFIGURATION", "HOST_NETWORK_CONFIGURATION", "HOST_ENTITES"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostCpuHardwareConfiguration.
        :type time_collected: datetime

        :param total_sockets:
            The value to assign to the total_sockets property of this HostCpuHardwareConfiguration.
        :type total_sockets: int

        :param vendor_name:
            The value to assign to the vendor_name property of this HostCpuHardwareConfiguration.
        :type vendor_name: str

        :param frequency_in_mhz:
            The value to assign to the frequency_in_mhz property of this HostCpuHardwareConfiguration.
        :type frequency_in_mhz: float

        :param cache_in_mb:
            The value to assign to the cache_in_mb property of this HostCpuHardwareConfiguration.
        :type cache_in_mb: float

        :param cpu_implementation:
            The value to assign to the cpu_implementation property of this HostCpuHardwareConfiguration.
        :type cpu_implementation: str

        :param model:
            The value to assign to the model property of this HostCpuHardwareConfiguration.
        :type model: str

        :param cpu_family:
            The value to assign to the cpu_family property of this HostCpuHardwareConfiguration.
        :type cpu_family: str

        :param cores_per_socket:
            The value to assign to the cores_per_socket property of this HostCpuHardwareConfiguration.
        :type cores_per_socket: int

        :param threads_per_socket:
            The value to assign to the threads_per_socket property of this HostCpuHardwareConfiguration.
        :type threads_per_socket: int

        :param hyper_threading_enabled:
            The value to assign to the hyper_threading_enabled property of this HostCpuHardwareConfiguration.
        :type hyper_threading_enabled: str

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'total_sockets': 'int',
            'vendor_name': 'str',
            'frequency_in_mhz': 'float',
            'cache_in_mb': 'float',
            'cpu_implementation': 'str',
            'model': 'str',
            'cpu_family': 'str',
            'cores_per_socket': 'int',
            'threads_per_socket': 'int',
            'hyper_threading_enabled': 'str'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'total_sockets': 'totalSockets',
            'vendor_name': 'vendorName',
            'frequency_in_mhz': 'frequencyInMhz',
            'cache_in_mb': 'cacheInMB',
            'cpu_implementation': 'cpuImplementation',
            'model': 'model',
            'cpu_family': 'cpuFamily',
            'cores_per_socket': 'coresPerSocket',
            'threads_per_socket': 'threadsPerSocket',
            'hyper_threading_enabled': 'hyperThreadingEnabled'
        }

        self._metric_name = None
        self._time_collected = None
        self._total_sockets = None
        self._vendor_name = None
        self._frequency_in_mhz = None
        self._cache_in_mb = None
        self._cpu_implementation = None
        self._model = None
        self._cpu_family = None
        self._cores_per_socket = None
        self._threads_per_socket = None
        self._hyper_threading_enabled = None
        self._metric_name = 'HOST_CPU_HARDWARE_CONFIGURATION'

    @property
    def total_sockets(self):
        """
        Gets the total_sockets of this HostCpuHardwareConfiguration.
        Total number of CPU Sockets


        :return: The total_sockets of this HostCpuHardwareConfiguration.
        :rtype: int
        """
        return self._total_sockets

    @total_sockets.setter
    def total_sockets(self, total_sockets):
        """
        Sets the total_sockets of this HostCpuHardwareConfiguration.
        Total number of CPU Sockets


        :param total_sockets: The total_sockets of this HostCpuHardwareConfiguration.
        :type: int
        """
        self._total_sockets = total_sockets

    @property
    def vendor_name(self):
        """
        Gets the vendor_name of this HostCpuHardwareConfiguration.
        Name of the CPU vendor


        :return: The vendor_name of this HostCpuHardwareConfiguration.
        :rtype: str
        """
        return self._vendor_name

    @vendor_name.setter
    def vendor_name(self, vendor_name):
        """
        Sets the vendor_name of this HostCpuHardwareConfiguration.
        Name of the CPU vendor


        :param vendor_name: The vendor_name of this HostCpuHardwareConfiguration.
        :type: str
        """
        self._vendor_name = vendor_name

    @property
    def frequency_in_mhz(self):
        """
        Gets the frequency_in_mhz of this HostCpuHardwareConfiguration.
        Clock frequency of the processor in megahertz


        :return: The frequency_in_mhz of this HostCpuHardwareConfiguration.
        :rtype: float
        """
        return self._frequency_in_mhz

    @frequency_in_mhz.setter
    def frequency_in_mhz(self, frequency_in_mhz):
        """
        Sets the frequency_in_mhz of this HostCpuHardwareConfiguration.
        Clock frequency of the processor in megahertz


        :param frequency_in_mhz: The frequency_in_mhz of this HostCpuHardwareConfiguration.
        :type: float
        """
        self._frequency_in_mhz = frequency_in_mhz

    @property
    def cache_in_mb(self):
        """
        Gets the cache_in_mb of this HostCpuHardwareConfiguration.
        Size of cache memory in megabytes


        :return: The cache_in_mb of this HostCpuHardwareConfiguration.
        :rtype: float
        """
        return self._cache_in_mb

    @cache_in_mb.setter
    def cache_in_mb(self, cache_in_mb):
        """
        Sets the cache_in_mb of this HostCpuHardwareConfiguration.
        Size of cache memory in megabytes


        :param cache_in_mb: The cache_in_mb of this HostCpuHardwareConfiguration.
        :type: float
        """
        self._cache_in_mb = cache_in_mb

    @property
    def cpu_implementation(self):
        """
        Gets the cpu_implementation of this HostCpuHardwareConfiguration.
        Model name of processor


        :return: The cpu_implementation of this HostCpuHardwareConfiguration.
        :rtype: str
        """
        return self._cpu_implementation

    @cpu_implementation.setter
    def cpu_implementation(self, cpu_implementation):
        """
        Sets the cpu_implementation of this HostCpuHardwareConfiguration.
        Model name of processor


        :param cpu_implementation: The cpu_implementation of this HostCpuHardwareConfiguration.
        :type: str
        """
        self._cpu_implementation = cpu_implementation

    @property
    def model(self):
        """
        Gets the model of this HostCpuHardwareConfiguration.
        CPU model


        :return: The model of this HostCpuHardwareConfiguration.
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """
        Sets the model of this HostCpuHardwareConfiguration.
        CPU model


        :param model: The model of this HostCpuHardwareConfiguration.
        :type: str
        """
        self._model = model

    @property
    def cpu_family(self):
        """
        Gets the cpu_family of this HostCpuHardwareConfiguration.
        Type of processor in the system


        :return: The cpu_family of this HostCpuHardwareConfiguration.
        :rtype: str
        """
        return self._cpu_family

    @cpu_family.setter
    def cpu_family(self, cpu_family):
        """
        Sets the cpu_family of this HostCpuHardwareConfiguration.
        Type of processor in the system


        :param cpu_family: The cpu_family of this HostCpuHardwareConfiguration.
        :type: str
        """
        self._cpu_family = cpu_family

    @property
    def cores_per_socket(self):
        """
        Gets the cores_per_socket of this HostCpuHardwareConfiguration.
        Number of cores per socket


        :return: The cores_per_socket of this HostCpuHardwareConfiguration.
        :rtype: int
        """
        return self._cores_per_socket

    @cores_per_socket.setter
    def cores_per_socket(self, cores_per_socket):
        """
        Sets the cores_per_socket of this HostCpuHardwareConfiguration.
        Number of cores per socket


        :param cores_per_socket: The cores_per_socket of this HostCpuHardwareConfiguration.
        :type: int
        """
        self._cores_per_socket = cores_per_socket

    @property
    def threads_per_socket(self):
        """
        Gets the threads_per_socket of this HostCpuHardwareConfiguration.
        Number of threads per socket


        :return: The threads_per_socket of this HostCpuHardwareConfiguration.
        :rtype: int
        """
        return self._threads_per_socket

    @threads_per_socket.setter
    def threads_per_socket(self, threads_per_socket):
        """
        Sets the threads_per_socket of this HostCpuHardwareConfiguration.
        Number of threads per socket


        :param threads_per_socket: The threads_per_socket of this HostCpuHardwareConfiguration.
        :type: int
        """
        self._threads_per_socket = threads_per_socket

    @property
    def hyper_threading_enabled(self):
        """
        Gets the hyper_threading_enabled of this HostCpuHardwareConfiguration.
        Indicates if hyper-threading is enabled or not


        :return: The hyper_threading_enabled of this HostCpuHardwareConfiguration.
        :rtype: str
        """
        return self._hyper_threading_enabled

    @hyper_threading_enabled.setter
    def hyper_threading_enabled(self, hyper_threading_enabled):
        """
        Sets the hyper_threading_enabled of this HostCpuHardwareConfiguration.
        Indicates if hyper-threading is enabled or not


        :param hyper_threading_enabled: The hyper_threading_enabled of this HostCpuHardwareConfiguration.
        :type: str
        """
        self._hyper_threading_enabled = hyper_threading_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .free_text_search_details import FreeTextSearchDetails
from .queryable_field_description import QueryableFieldDescription
from .resource_summary import ResourceSummary
from .resource_summary_collection import ResourceSummaryCollection
from .resource_type import ResourceType
from .search_context import SearchContext
from .search_details import SearchDetails
from .structured_search_details import StructuredSearchDetails

# Maps type names to classes for resource_search services.
resource_search_type_mapping = {
    "FreeTextSearchDetails": FreeTextSearchDetails,
    "QueryableFieldDescription": QueryableFieldDescription,
    "ResourceSummary": ResourceSummary,
    "ResourceSummaryCollection": ResourceSummaryCollection,
    "ResourceType": ResourceType,
    "SearchContext": SearchContext,
    "SearchDetails": SearchDetails,
    "StructuredSearchDetails": StructuredSearchDetails
}
